Class: Revox::Models::AssistantCloneResponse::Assistant::Zoho::FieldMapping

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/assistant_clone_response.rb,
sig/revox/models/assistant_clone_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(connection_id:, field_mapping:, log_call_activity:, module_:, outcomes:, template: nil) ⇒ FieldMapping

Some parameter documentations has been truncated, see Revox::Models::AssistantCloneResponse::Assistant::Zoho for more details.

Parameters:

  • connection_id (String)

    The Nango connection ID linking the org's Zoho CRM account to Revox.

  • field_mapping (Array<Revox::Models::AssistantCloneResponse::Assistant::Zoho::FieldMapping>)

    Maps extracted call fields (structured_output / prompt variables) onto Zoho fiel

  • log_call_activity (Boolean)

    When true, also log the call as a record in Zoho's Calls module (related to the

  • module_ (String)

    Zoho module the prospect record is upserted into (e.g. 'Leads' or 'Contacts').

  • outcomes (Array<Symbol, Revox::Models::AssistantCloneResponse::Assistant::Zoho::Outcome>)

    Which call outcomes trigger the Zoho push (e.g. ['interested', 'none']). Use 'no

  • template (String, nil) (defaults to: nil)

    Optional Note body template. Supports {summary}, {outcome}, {phone}, {{cal

  • source: (String)
  • zoho_field: (String)


1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
# File 'lib/revox/models/assistant_clone_response.rb', line 1470

class FieldMapping < Revox::Internal::Type::BaseModel
  # @!attribute source
  #   Source key to read from the call: a structured_output field name, falling back
  #   to a prompt variable of the same name.
  #
  #   @return [String]
  required :source, String

  # @!attribute zoho_field
  #   Destination Zoho field API name on the upserted record (e.g. 'Email', 'Company',
  #   or a custom 'Budget\_\_c').
  #
  #   @return [String]
  required :zoho_field, String

  # @!method initialize(source:, zoho_field:)
  #   Some parameter documentations has been truncated, see
  #   {Revox::Models::AssistantCloneResponse::Assistant::Zoho::FieldMapping} for more
  #   details.
  #
  #   @param source [String] Source key to read from the call: a structured_output field name, falling back t
  #
  #   @param zoho_field [String] Destination Zoho field API name on the upserted record (e.g. 'Email', 'Company',
end

Instance Attribute Details

#sourceString

Source key to read from the call: a structured_output field name, falling back to a prompt variable of the same name.

Parameters:

  • value (String)

Returns:

  • (String)


1476
# File 'lib/revox/models/assistant_clone_response.rb', line 1476

required :source, String

#zoho_fieldString

Destination Zoho field API name on the upserted record (e.g. 'Email', 'Company', or a custom 'Budget__c').

Parameters:

  • value (String)

Returns:

  • (String)


1483
# File 'lib/revox/models/assistant_clone_response.rb', line 1483

required :zoho_field, String

Instance Method Details

#to_hash{ source: String, zoho_field: String }

Returns:

  • ({ source: String, zoho_field: String })


1204
# File 'sig/revox/models/assistant_clone_response.rbs', line 1204

def to_hash: -> { source: String, zoho_field: String }