Class: Revox::Models::AssistantCreateParams::CallRetryConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/assistant_create_params.rb,
sig/revox/models/assistant_create_params.rbs

Defined Under Namespace

Modules: AllowedDay Classes: CallingWindow

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



368
# File 'sig/revox/models/assistant_create_params.rbs', line 368

def initialize: (

Instance Attribute Details

#allowed_daysArray<Symbol, Revox::Models::AssistantCreateParams::CallRetryConfig::AllowedDay>

Days of the week when calls are allowed, in the recipient's timezone. Default: Monday through Friday.

Parameters:

  • value (::Array[Revox::Models::AssistantCreateParams::CallRetryConfig::allowed_day])

Returns:



485
486
# File 'lib/revox/models/assistant_create_params.rb', line 485

required :allowed_days,
-> { Revox::Internal::Type::ArrayOf[enum: Revox::AssistantCreateParams::CallRetryConfig::AllowedDay] }

#call_twice_in_a_rowBoolean

If true and max_retry_attempts >= 2, attempt #2 fires immediately (skipping retry_delay_seconds) when attempt #1 didn't reach a human. Calling-window/allowed-days checks still apply. Only affects the 1→2 transition. Default: false.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


495
# File 'lib/revox/models/assistant_create_params.rb', line 495

required :call_twice_in_a_row, Revox::Internal::Type::Boolean

#calling_windowsArray<Revox::Models::AssistantCreateParams::CallRetryConfig::CallingWindow>

Parameters:

  • value (::Array[Revox::AssistantCreateParams::CallRetryConfig::CallingWindow])

Returns:



500
501
# File 'lib/revox/models/assistant_create_params.rb', line 500

required :calling_windows,
-> { Revox::Internal::Type::ArrayOf[Revox::AssistantCreateParams::CallRetryConfig::CallingWindow] }

#max_retry_attemptsInteger

Maximum number of call retry attempts. Default: 3.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


507
# File 'lib/revox/models/assistant_create_params.rb', line 507

required :max_retry_attempts, Integer

#timezoneString?

Optional IANA timezone identifier to override the automatic timezone detection from phone number. If not provided, timezone is determined from the recipient's phone number country code. Examples: 'America/New_York', 'Europe/Paris'.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


515
# File 'lib/revox/models/assistant_create_params.rb', line 515

optional :timezone, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/revox/models/assistant_create_params.rb', line 545

Instance Method Details

#to_hash{

Returns:

  • ({)


376
# File 'sig/revox/models/assistant_create_params.rbs', line 376

def to_hash: -> {