Class: Revox::Models::AssistantCreateParams::Slack::Channel

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/assistant_create_params.rb,
sig/revox/models/assistant_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channels:, connection_id:, outcomes:, template: nil) ⇒ Channel

Some parameter documentations has been truncated, see Revox::Models::AssistantCreateParams::Slack for more details.

Slack notification config. When set, posts a message to the chosen channel after a call ends with one of the configured outcomes.

{{call_

Parameters:

  • channels (Array<Revox::Models::AssistantCreateParams::Slack::Channel>)

    The Slack channels eligible to receive the notification. When more than one is c

  • connection_id (String)

    The Nango connection ID linking the org's Slack workspace to Revox.

  • outcomes (Array<Symbol, Revox::Models::AssistantCreateParams::Slack::Outcome>)

    Which call outcomes trigger a Slack notification (e.g. ['interested', 'none']).

  • template (String, nil) (defaults to: nil)

    Optional message template. Supports {summary}, {outcome}, {phone},

  • id: (String)
  • name: (String, nil)


1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
# File 'lib/revox/models/assistant_create_params.rb', line 1142

class Channel < Revox::Internal::Type::BaseModel
  # @!attribute id
  #   The Slack channel ID (e.g. 'C01234567').
  #
  #   @return [String]
  required :id, String

  # @!attribute name
  #   Human-readable Slack channel name, cached for display in the UI and given to the
  #   LLM when the agent prompt routes by channel name.
  #
  #   @return [String, nil]
  optional :name, String, nil?: true

  # @!method initialize(id:, name: nil)
  #   Some parameter documentations has been truncated, see
  #   {Revox::Models::AssistantCreateParams::Slack::Channel} for more details.
  #
  #   @param id [String] The Slack channel ID (e.g. 'C01234567').
  #
  #   @param name [String, nil] Human-readable Slack channel name, cached for display in the UI and given to the
end

Instance Attribute Details

#idString

The Slack channel ID (e.g. 'C01234567').

Parameters:

  • value (String)

Returns:

  • (String)


1147
# File 'lib/revox/models/assistant_create_params.rb', line 1147

required :id, String

#nameString?

Human-readable Slack channel name, cached for display in the UI and given to the LLM when the agent prompt routes by channel name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1154
# File 'lib/revox/models/assistant_create_params.rb', line 1154

optional :name, String, nil?: true

Instance Method Details

#to_hash{ id: String, name: String? }

Returns:

  • ({ id: String, name: String? })


918
# File 'sig/revox/models/assistant_create_params.rbs', line 918

def to_hash: -> { id: String, name: String? }