Module: Revox::Models::AssistantCreateParams::Slack::Outcome

Extended by:
Internal::Type::Enum
Defined in:
lib/revox/models/assistant_create_params.rb,
sig/revox/models/assistant_create_params.rbs

Constant Summary collapse

NOT_INTERESTED =

Returns:

  • (:not_interested)
:not_interested
INTERESTED =

Returns:

  • (:interested)
:interested
COMPLETED =

Returns:

  • (:completed)
:completed
REQUESTED_CALLBACK_LATER =

Returns:

  • (:requested_callback_later)
:requested_callback_later
REQUESTED_CALLBACK_NEW_NUMBER =

Returns:

  • (:requested_callback_new_number)
:requested_callback_new_number
DO_NOT_CONTACT =

Returns:

  • (:do_not_contact)
:do_not_contact
AI_AVERSE =

Returns:

  • (:ai_averse)
:ai_averse
NONE =

Returns:

  • (:none)
:none

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(channel_id:, connection_id:, outcomes:, channel_name: nil, template: nil) ⇒ Object

Some parameter documentations has been truncated, see Revox::Models::AssistantCreateParams::Slack for more details.

Slack notification config. When set, posts a message to the chosen channel after a call ends with one of the configured outcomes.

{{call_

Parameters:

  • channel_id (String)

    The Slack channel ID where the notification will be posted.

  • connection_id (String)

    The Nango connection ID linking the org's Slack workspace to Revox.

  • outcomes (Array<Symbol, Revox::Models::AssistantCreateParams::Slack::Outcome>)

    Which call outcomes trigger a Slack notification (e.g. ['interested', 'none']).

  • channel_name (String, nil) (defaults to: nil)

    Human-readable Slack channel name, cached for display in the UI.

  • template (String, nil) (defaults to: nil)

    Optional message template. Supports {summary}, {outcome}, {phone},



1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
# File 'lib/revox/models/assistant_create_params.rb', line 1159

module Outcome
  extend Revox::Internal::Type::Enum

  NOT_INTERESTED = :not_interested
  INTERESTED = :interested
  COMPLETED = :completed
  REQUESTED_CALLBACK_LATER = :requested_callback_later
  REQUESTED_CALLBACK_NEW_NUMBER = :requested_callback_new_number
  DO_NOT_CONTACT = :do_not_contact
  AI_AVERSE = :ai_averse
  NONE = :none

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Revox::Models::AssistantCreateParams::Slack::outcome]

Returns:

  • (::Array[Revox::Models::AssistantCreateParams::Slack::outcome])


963
# File 'sig/revox/models/assistant_create_params.rbs', line 963

def self?.values: -> ::Array[Revox::Models::AssistantCreateParams::Slack::outcome]