Module: Revox::Models::AssistantUpdateParams::AfterCallSMSOutcome

Extended by:
Internal::Type::Enum
Defined in:
lib/revox/models/assistant_update_params.rb,
sig/revox/models/assistant_update_params.rbs

Constant Summary collapse

NOT_INTERESTED =

Returns:

  • (:not_interested)
:not_interested
INTERESTED =

Returns:

  • (:interested)
:interested
COMPLETED =

Returns:

  • (:completed)
:completed
REQUESTED_CALLBACK_LATER =

Returns:

  • (:requested_callback_later)
:requested_callback_later
REQUESTED_CALLBACK_NEW_NUMBER =

Returns:

  • (:requested_callback_new_number)
:requested_callback_new_number
DO_NOT_CONTACT =

Returns:

  • (:do_not_contact)
:do_not_contact
AI_AVERSE =

Returns:

  • (:ai_averse)
:ai_averse
NONE =

Returns:

  • (:none)
:none

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(id:, after_call_sms_outcomes: nil, after_call_sms_prompt: nil, background_sound: nil, background_sound_volume: nil, calendly: nil, call_retry_config: nil, cartesia_dictionary_pronunciation_id: nil, custom_tools: nil, email_notification_address: nil, email_notification_language: nil, email_notification_outcomes: nil, end_of_call_sentence: nil, faq_items: nil, first_sentence: nil, first_sentence_delay_ms: nil, first_sentence_mode: nil, from_phone_number: nil, human_transfer_mode: nil, ivr_navigation_enabled: nil, llm_model: nil, logo_url: nil, max_call_duration_secs: nil, max_duration_end_message: nil, name: nil, position: nil, prompt: nil, prompt_flow: nil, slack: nil, sms_enabled: nil, sms_template: nil, structured_output_config: nil, structured_output_prompt: nil, stt_context: nil, stt_model: nil, thinking_sound: nil, thinking_sound_probability: nil, thinking_sound_volume: nil, transfer_phone_number: nil, type: nil, voice: nil, voicemail_message: nil, voicemail_sms_prompt: nil, warm_transfer_summary_instructions: nil, webhook_url: nil, zoho: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Revox::Models::AssistantUpdateParams for more details.

Parameters:

  • id (String)
  • after_call_sms_outcomes (Array<Symbol, Revox::Models::AssistantUpdateParams::AfterCallSMSOutcome>, nil) (defaults to: nil)

    Which call outcomes trigger the after-call SMS. When empty or null, no after-cal

  • after_call_sms_prompt (String, nil) (defaults to: nil)

    Prompt / instructions for the after-call SMS. Supports {variable} placeholders

  • background_sound (Symbol, Revox::Models::AssistantUpdateParams::BackgroundSound, nil) (defaults to: nil)

    Ambient background sound to play during the call. null/omitted disables it.

  • background_sound_volume (Float) (defaults to: nil)

    Volume of the ambient background sound (0 = silent, 1 = max).

  • calendly (Revox::Models::AssistantUpdateParams::Calendly, nil) (defaults to: nil)
  • call_retry_config (Revox::Models::AssistantUpdateParams::CallRetryConfig) (defaults to: nil)

    Configuration for call retry behavior including time windows, delays, and max it

  • cartesia_dictionary_pronunciation_id (String, nil) (defaults to: nil)

    Optional Cartesia pronunciation dictionary ID to use for this assistant's calls.

  • custom_tools (Array<Revox::Models::AssistantUpdateParams::CustomTool>, nil) (defaults to: nil)

    Custom API tools the assistant can call during conversations. Each tool defines

  • email_notification_address (String, nil) (defaults to: nil)

    Email address(es) to receive notifications when a call ends with a matching outc

  • email_notification_language (Symbol, Revox::Models::AssistantUpdateParams::EmailNotificationLanguage) (defaults to: nil)

    The language used for the notification email content. One of "en" or "fr". Defau

  • email_notification_outcomes (Array<Symbol, Revox::Models::AssistantUpdateParams::EmailNotificationOutcome>, nil) (defaults to: nil)

    Which call outcomes trigger an email notification. E.g. ["interested", "complete

  • end_of_call_sentence (String) (defaults to: nil)

    Optional message to say when the agent decides to end the call.

  • faq_items (Array<Revox::Models::AssistantUpdateParams::FaqItem>) (defaults to: nil)

    FAQ items to associate with this assistant. When provided, replaces all existing

  • first_sentence (String) (defaults to: nil)

    The first sentence to use for the call. This will be given to the LLM

  • first_sentence_delay_ms (Integer) (defaults to: nil)

    Delay in milliseconds before speaking the first sentence. Default: 400.

  • first_sentence_mode (Symbol, Revox::Models::AssistantUpdateParams::FirstSentenceMode) (defaults to: nil)

    How the first sentence should be handled. "generated" means the LLM will generat

  • from_phone_number (String, nil) (defaults to: nil)

    Override the default outbound phone number for calls placed with this assistant.

  • human_transfer_mode (Symbol, Revox::Models::AssistantUpdateParams::HumanTransferMode, nil) (defaults to: nil)

    When transfer_phone_number is set: "warm" (AI bridges) or "cold" (SIP REFER; tru

  • ivr_navigation_enabled (Boolean) (defaults to: nil)

    Enable IVR navigation tools. When enabled, the assistant can send DTMF tones and

  • llm_model (Revox::Models::AssistantUpdateParams::LlmModel::UnionMember0, Revox::Models::AssistantUpdateParams::LlmModel::UnionMember1, Revox::Models::AssistantUpdateParams::LlmModel::UnionMember2, Revox::Models::AssistantUpdateParams::LlmModel::UnionMember3) (defaults to: nil)
  • logo_url (String, nil) (defaults to: nil)

    Public URL of the brand logo shown on the assistant's demo page. Upload a new lo

  • max_call_duration_secs (Float) (defaults to: nil)

    The maximum duration of the call in seconds. This is the maximum time the call w

  • max_duration_end_message (String, nil) (defaults to: nil)

    Optional message the agent will say, without being interruptible, when the call

  • name (String) (defaults to: nil)
  • position (Revox::Models::AssistantUpdateParams::Position, nil) (defaults to: nil)

    Canvas position of this assistant's node in its multi-step flow editor.

  • prompt (String) (defaults to: nil)

    The prompt to use for the call. This will be given to the LLM (gpt-4.1)

  • prompt_flow (Revox::Models::AssistantUpdateParams::PromptFlow, nil) (defaults to: nil)

    Visual prompt constructor data (nodes, edges, positions). Used by the UI to re-o

  • slack (Revox::Models::AssistantUpdateParams::Slack, nil) (defaults to: nil)

    Slack notification config. When set, posts a message to the chosen channel after

  • sms_enabled (Boolean) (defaults to: nil)

    Enable SMS tool during calls. When enabled, the agent can send SMS messages to t

  • sms_template (String, nil) (defaults to: nil)

    Hardcoded SMS template to send during calls. When set, this exact text is sent i

  • structured_output_config (Array<Revox::Models::AssistantUpdateParams::StructuredOutputConfig>) (defaults to: nil)

    The structured output config to use for the call. This is used to extract the da

  • structured_output_prompt (String, nil) (defaults to: nil)

    Custom prompt for structured data extraction. If not provided, a default prompt

  • stt_context (Revox::Models::AssistantUpdateParams::SttContext, nil) (defaults to: nil)

    Assistant-level speech-to-text context: structured general key/value pairs plu

  • stt_model (Symbol, Revox::Models::AssistantUpdateParams::SttModel) (defaults to: nil)

    Transcriber (speech-to-text) model. Defaults to the newest Soniox realtime model

  • thinking_sound (Symbol, Revox::Models::AssistantUpdateParams::ThinkingSound, nil) (defaults to: nil)

    Audio clip to play while the agent is processing a response. One of the built-in

  • thinking_sound_probability (Float) (defaults to: nil)

    Probability [0..1] that the thinking sound plays on any given turn; otherwise th

  • thinking_sound_volume (Float) (defaults to: nil)

    Volume of the thinking sound (0 = silent, 1 = max).

  • transfer_phone_number (String, nil) (defaults to: nil)

    Phone number to transfer calls to when users request to speak to a human agent i

  • type (Symbol, Revox::Models::AssistantUpdateParams::Type) (defaults to: nil)

    Assistant kind. 'standalone' (default) is a normal assistant, 'multi-step' orche

  • voice (Revox::Models::AssistantUpdateParams::Voice) (defaults to: nil)

    The voice to use for the call. You can get the list of voices using the /voices

  • voicemail_message (String, nil) (defaults to: nil)

    If set, when voicemail is detected the agent will speak this message then hang u

  • voicemail_sms_prompt (String, nil) (defaults to: nil)

    SMS message to send when the call reaches voicemail. Supports {variable} place

  • warm_transfer_summary_instructions (String, nil) (defaults to: nil)

    When using warm transfer: extra instructions for the supervisor handoff summary.

  • webhook_url (String) (defaults to: nil)

    The webhook URL to call when the call is completed.

  • zoho (Revox::Models::AssistantUpdateParams::Zoho, nil) (defaults to: nil)

    Zoho CRM integration config. When set, upserts the prospect (keyed on phone) int

  • request_options (Revox::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
# File 'lib/revox/models/assistant_update_params.rb', line 437

module AfterCallSMSOutcome
  extend Revox::Internal::Type::Enum

  NOT_INTERESTED = :not_interested
  INTERESTED = :interested
  COMPLETED = :completed
  REQUESTED_CALLBACK_LATER = :requested_callback_later
  REQUESTED_CALLBACK_NEW_NUMBER = :requested_callback_new_number
  DO_NOT_CONTACT = :do_not_contact
  AI_AVERSE = :ai_averse
  NONE = :none

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Revox::Models::AssistantUpdateParams::after_call_sms_outcome]

Returns:

  • (::Array[Revox::Models::AssistantUpdateParams::after_call_sms_outcome])


332
# File 'sig/revox/models/assistant_update_params.rbs', line 332

def self?.values: -> ::Array[Revox::Models::AssistantUpdateParams::after_call_sms_outcome]