Class: Revox::Models::AssistantUpdateParams::Slack::Channel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::AssistantUpdateParams::Slack::Channel
- Defined in:
- lib/revox/models/assistant_update_params.rb,
sig/revox/models/assistant_update_params.rbs
Instance Attribute Summary collapse
-
#id ⇒ String
The Slack channel ID (e.g. 'C01234567').
-
#name ⇒ String?
Human-readable Slack channel name, cached for display in the UI and given to the LLM when the agent prompt routes by channel name.
Instance Method Summary collapse
-
#initialize(channels:, connection_id:, outcomes:, template: nil) ⇒ Channel
constructor
Some parameter documentations has been truncated, see Revox::Models::AssistantUpdateParams::Slack for more details.
- #to_hash ⇒ { id: String, name: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channels:, connection_id:, outcomes:, template: nil) ⇒ Channel
Some parameter documentations has been truncated, see Revox::Models::AssistantUpdateParams::Slack for more details.
Slack notification config. When set, posts a message to the chosen channel after a call ends with one of the configured outcomes.
{{call_
1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 |
# File 'lib/revox/models/assistant_update_params.rb', line 1149 class Channel < Revox::Internal::Type::BaseModel # @!attribute id # The Slack channel ID (e.g. 'C01234567'). # # @return [String] required :id, String # @!attribute name # Human-readable Slack channel name, cached for display in the UI and given to the # LLM when the agent prompt routes by channel name. # # @return [String, nil] optional :name, String, nil?: true # @!method initialize(id:, name: nil) # Some parameter documentations has been truncated, see # {Revox::Models::AssistantUpdateParams::Slack::Channel} for more details. # # @param id [String] The Slack channel ID (e.g. 'C01234567'). # # @param name [String, nil] Human-readable Slack channel name, cached for display in the UI and given to the end |
Instance Attribute Details
#id ⇒ String
The Slack channel ID (e.g. 'C01234567').
1154 |
# File 'lib/revox/models/assistant_update_params.rb', line 1154 required :id, String |
#name ⇒ String?
Human-readable Slack channel name, cached for display in the UI and given to the LLM when the agent prompt routes by channel name.
1161 |
# File 'lib/revox/models/assistant_update_params.rb', line 1161 optional :name, String, nil?: true |
Instance Method Details
#to_hash ⇒ { id: String, name: String? }
927 |
# File 'sig/revox/models/assistant_update_params.rbs', line 927
def to_hash: -> { id: String, name: String? }
|