Class: Revox::Models::AssistantUpdateResponse::Assistant::Calendly
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::AssistantUpdateResponse::Assistant::Calendly
- Defined in:
- lib/revox/models/assistant_update_response.rb,
sig/revox/models/assistant_update_response.rbs
Overview
Instance Attribute Summary collapse
-
#connection_id ⇒ String
The connection ID representing the link between your Calendly account and Revox.
-
#event_type_id ⇒ String
The event type ID representing the event type to schedule.
Instance Method Summary collapse
-
#initialize ⇒ Calendly
constructor
A new instance of Calendly.
- #to_hash ⇒ { connection_id: String, event_type_id: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Calendly
Returns a new instance of Calendly.
349 |
# File 'sig/revox/models/assistant_update_response.rbs', line 349
def initialize: (connection_id: String, event_type_id: String) -> void
|
Instance Attribute Details
#connection_id ⇒ String
The connection ID representing the link between your Calendly account and Revox.
503 |
# File 'lib/revox/models/assistant_update_response.rb', line 503 required :connection_id, String |
#event_type_id ⇒ String
The event type ID representing the event type to schedule. (eg: https://api.calendly.com/event_types/b2330295-2a91-4a1d-bb73-99e7707663d5)
510 |
# File 'lib/revox/models/assistant_update_response.rb', line 510 required :event_type_id, String |
Instance Method Details
#to_hash ⇒ { connection_id: String, event_type_id: String }
351 |
# File 'sig/revox/models/assistant_update_response.rbs', line 351
def to_hash: -> { connection_id: String, event_type_id: String }
|