Class: Revox::Models::CallCreateParams::Assistant::Zoho::FieldMapping
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::CallCreateParams::Assistant::Zoho::FieldMapping
- Defined in:
- lib/revox/models/call_create_params.rb,
sig/revox/models/call_create_params.rbs
Instance Attribute Summary collapse
-
#source ⇒ String
Source key to read from the call: a structured_output field name, falling back to a prompt variable of the same name.
-
#zoho_field ⇒ String
Destination Zoho field API name on the upserted record (e.g. 'Email', 'Company', or a custom 'Budget__c').
Instance Method Summary collapse
-
#initialize(connection_id:, field_mapping:, log_call_activity:, module_:, outcomes:, template: nil) ⇒ FieldMapping
constructor
Some parameter documentations has been truncated, see Revox::Models::CallCreateParams::Assistant::Zoho for more details.
- #to_hash ⇒ { source: String, zoho_field: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_id:, field_mapping:, log_call_activity:, module_:, outcomes:, template: nil) ⇒ FieldMapping
Some parameter documentations has been truncated, see Revox::Models::CallCreateParams::Assistant::Zoho for more details.
Zoho CRM integration config. When set, upserts the prospect (keyed on phone) into the chosen module and attaches a Note with the call summary after a call ends with one of the configured outcomes.
1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 |
# File 'lib/revox/models/call_create_params.rb', line 1598 class FieldMapping < Revox::Internal::Type::BaseModel # @!attribute source # Source key to read from the call: a structured_output field name, falling back # to a prompt variable of the same name. # # @return [String] required :source, String # @!attribute zoho_field # Destination Zoho field API name on the upserted record (e.g. 'Email', 'Company', # or a custom 'Budget\_\_c'). # # @return [String] required :zoho_field, String # @!method initialize(source:, zoho_field:) # Some parameter documentations has been truncated, see # {Revox::Models::CallCreateParams::Assistant::Zoho::FieldMapping} for more # details. # # @param source [String] Source key to read from the call: a structured_output field name, falling back t # # @param zoho_field [String] Destination Zoho field API name on the upserted record (e.g. 'Email', 'Company', end |
Instance Attribute Details
#source ⇒ String
Source key to read from the call: a structured_output field name, falling back to a prompt variable of the same name.
1604 |
# File 'lib/revox/models/call_create_params.rb', line 1604 required :source, String |
#zoho_field ⇒ String
Destination Zoho field API name on the upserted record (e.g. 'Email', 'Company', or a custom 'Budget__c').
1611 |
# File 'lib/revox/models/call_create_params.rb', line 1611 required :zoho_field, String |
Instance Method Details
#to_hash ⇒ { source: String, zoho_field: String }
1281 |
# File 'sig/revox/models/call_create_params.rbs', line 1281
def to_hash: -> { source: String, zoho_field: String }
|