Class: Revox::Models::CallCreateResponse::Call::CallRetryConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::CallCreateResponse::Call::CallRetryConfig
- Defined in:
- lib/revox/models/call_create_response.rb,
sig/revox/models/call_create_response.rbs
Overview
Defined Under Namespace
Modules: AllowedDay Classes: CallingWindow
Instance Attribute Summary collapse
-
#allowed_days ⇒ Array<Symbol, Revox::Models::CallCreateResponse::Call::CallRetryConfig::AllowedDay>
Days of the week when calls are allowed, in the recipient's timezone.
-
#call_twice_in_a_row ⇒ Boolean
If true and max_retry_attempts >= 2, attempt #2 fires immediately (skipping retry_delay_seconds) when attempt #1 didn't reach a human.
- #calling_windows ⇒ Array<Revox::Models::CallCreateResponse::Call::CallRetryConfig::CallingWindow>
-
#max_retry_attempts ⇒ Integer
Maximum number of call retry attempts.
-
#timezone ⇒ String?
Optional IANA timezone identifier to override the automatic timezone detection from phone number.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1912 |
# File 'sig/revox/models/call_create_response.rbs', line 1912
def initialize: (
|
Instance Attribute Details
#allowed_days ⇒ Array<Symbol, Revox::Models::CallCreateResponse::Call::CallRetryConfig::AllowedDay>
Days of the week when calls are allowed, in the recipient's timezone. Default: Monday through Friday.
2300 2301 |
# File 'lib/revox/models/call_create_response.rb', line 2300 required :allowed_days, -> { Revox::Internal::Type::ArrayOf[enum: Revox::Models::CallCreateResponse::Call::CallRetryConfig::AllowedDay] } |
#call_twice_in_a_row ⇒ Boolean
If true and max_retry_attempts >= 2, attempt #2 fires immediately (skipping retry_delay_seconds) when attempt #1 didn't reach a human. Calling-window/allowed-days checks still apply. Only affects the 1→2 transition. Default: false.
2310 |
# File 'lib/revox/models/call_create_response.rb', line 2310 required :call_twice_in_a_row, Revox::Internal::Type::Boolean |
#calling_windows ⇒ Array<Revox::Models::CallCreateResponse::Call::CallRetryConfig::CallingWindow>
2315 2316 |
# File 'lib/revox/models/call_create_response.rb', line 2315 required :calling_windows, -> { Revox::Internal::Type::ArrayOf[Revox::Models::CallCreateResponse::Call::CallRetryConfig::CallingWindow] } |
#max_retry_attempts ⇒ Integer
Maximum number of call retry attempts. Default: 3.
2322 |
# File 'lib/revox/models/call_create_response.rb', line 2322 required :max_retry_attempts, Integer |
#timezone ⇒ String?
Optional IANA timezone identifier to override the automatic timezone detection from phone number. If not provided, timezone is determined from the recipient's phone number country code. Examples: 'America/New_York', 'Europe/Paris'.
2330 |
# File 'lib/revox/models/call_create_response.rb', line 2330 optional :timezone, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/revox/models/call_create_response.rb', line 2360
|
Instance Method Details
#to_hash ⇒ {
1920 |
# File 'sig/revox/models/call_create_response.rbs', line 1920
def to_hash: -> {
|