Class: Revox::Models::CallExportParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::CallExportParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/revox/models/call_export_params.rb,
sig/revox/models/call_export_params.rbs
Overview
Defined Under Namespace
Classes: Filters
Instance Attribute Summary collapse
- #filters ⇒ Revox::Models::CallExportParams::Filters
-
#include_metadata ⇒ Boolean?
Whether to include the metadata in the CSV file.
-
#include_structured_output_fields ⇒ Boolean?
Whether to include the structured output fields in the CSV file.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
25 |
# File 'sig/revox/models/call_export_params.rbs', line 25
def initialize: (
|
Instance Attribute Details
#filters ⇒ Revox::Models::CallExportParams::Filters
13 |
# File 'lib/revox/models/call_export_params.rb', line 13 required :filters, -> { Revox::CallExportParams::Filters } |
#include_metadata ⇒ Boolean?
Whether to include the metadata in the CSV file. These are the fields you (optionally) attached when placing the call.
20 |
# File 'lib/revox/models/call_export_params.rb', line 20 optional :include_metadata, Revox::Internal::Type::Boolean |
#include_structured_output_fields ⇒ Boolean?
Whether to include the structured output fields in the CSV file. These are generated by our AI agent during call analysis phase.
27 |
# File 'lib/revox/models/call_export_params.rb', line 27 optional :include_structured_output_fields, Revox::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/revox/models/call_export_params.rbs', line 32
def to_hash: -> {
|