Class: Revox::Models::CallSearchResponse::Call::Assistant::CallRetryConfig::CallingWindow

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/call_search_response.rb,
sig/revox/models/call_search_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



594
# File 'sig/revox/models/call_search_response.rbs', line 594

def initialize: (

Instance Attribute Details

#calling_window_end_timeString

End time for the calling window in the recipient's timezone (or timezone_override if provided). Format: 'HH:mm' (24-hour) or 'H:mma' (12-hour). Examples: '17:00', '6pm'. Default: '18:00'.

Parameters:

  • value (String)

Returns:

  • (String)


857
# File 'lib/revox/models/call_search_response.rb', line 857

required :calling_window_end_time, String

#calling_window_start_timeString

Start time for the calling window in the recipient's timezone (or timezone_override if provided). Format: 'HH:mm' (24-hour) or 'H:mma' (12-hour). Examples: '09:00', '10am'. Default: '10:00'.

Parameters:

  • value (String)

Returns:

  • (String)


865
# File 'lib/revox/models/call_search_response.rb', line 865

required :calling_window_start_time, String

#retry_delay_secondsInteger

Delay between retry attempts in seconds. Default: 7200 (2 hours).

Parameters:

  • value (Integer)

Returns:

  • (Integer)


871
# File 'lib/revox/models/call_search_response.rb', line 871

required :retry_delay_seconds, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


600
# File 'sig/revox/models/call_search_response.rbs', line 600

def to_hash: -> {