Class: Revox::Models::CallSearchResponse::Call::Assistant::Slack::Channel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::CallSearchResponse::Call::Assistant::Slack::Channel
- Defined in:
- lib/revox/models/call_search_response.rb,
sig/revox/models/call_search_response.rbs
Instance Attribute Summary collapse
-
#id ⇒ String
The Slack channel ID (e.g. 'C01234567').
-
#name ⇒ String?
Human-readable Slack channel name, cached for display in the UI and given to the LLM when the agent prompt routes by channel name.
Instance Method Summary collapse
-
#initialize(channels:, connection_id:, outcomes:, template: nil) ⇒ Channel
constructor
Some parameter documentations has been truncated, see Revox::Models::CallSearchResponse::Call::Assistant::Slack for more details.
- #to_hash ⇒ { id: String, name: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channels:, connection_id:, outcomes:, template: nil) ⇒ Channel
Some parameter documentations has been truncated, see Revox::Models::CallSearchResponse::Call::Assistant::Slack for more details.
{{call_
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 |
# File 'lib/revox/models/call_search_response.rb', line 1446 class Channel < Revox::Internal::Type::BaseModel # @!attribute id # The Slack channel ID (e.g. 'C01234567'). # # @return [String] required :id, String # @!attribute name # Human-readable Slack channel name, cached for display in the UI and given to the # LLM when the agent prompt routes by channel name. # # @return [String, nil] optional :name, String, nil?: true # @!method initialize(id:, name: nil) # Some parameter documentations has been truncated, see # {Revox::Models::CallSearchResponse::Call::Assistant::Slack::Channel} for more # details. # # @param id [String] The Slack channel ID (e.g. 'C01234567'). # # @param name [String, nil] Human-readable Slack channel name, cached for display in the UI and given to the end |
Instance Attribute Details
#id ⇒ String
The Slack channel ID (e.g. 'C01234567').
1451 |
# File 'lib/revox/models/call_search_response.rb', line 1451 required :id, String |
#name ⇒ String?
Human-readable Slack channel name, cached for display in the UI and given to the LLM when the agent prompt routes by channel name.
1458 |
# File 'lib/revox/models/call_search_response.rb', line 1458 optional :name, String, nil?: true |
Instance Method Details
#to_hash ⇒ { id: String, name: String? }
1100 |
# File 'sig/revox/models/call_search_response.rbs', line 1100
def to_hash: -> { id: String, name: String? }
|