Class: Revox::Models::CallSearchResponse::Call::LlmModel::UnionMember2
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::CallSearchResponse::Call::LlmModel::UnionMember2
- Defined in:
- lib/revox/models/call_search_response.rb,
sig/revox/models/call_search_response.rbs
Instance Attribute Summary collapse
-
#api_key ⇒ String
API key sent as Bearer token to the custom endpoint.
-
#api_url ⇒ String
Base URL for the OpenAI-compatible API, e.g.
-
#model_name ⇒ String
Model name as expected by the provider, e.g.
-
#type ⇒ Symbol, :custom
OpenAI-compatible chat completions API (bring your own endpoint and key).
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
2539 |
# File 'sig/revox/models/call_search_response.rbs', line 2539
def initialize: (
|
Instance Attribute Details
#api_key ⇒ String
API key sent as Bearer token to the custom endpoint.
2992 |
# File 'lib/revox/models/call_search_response.rb', line 2992 required :api_key, String |
#api_url ⇒ String
Base URL for the OpenAI-compatible API, e.g. https://api.together.xyz/v1
2998 |
# File 'lib/revox/models/call_search_response.rb', line 2998 required :api_url, String |
#model_name ⇒ String
Model name as expected by the provider, e.g. meta-llama/llama-3-70b
3004 |
# File 'lib/revox/models/call_search_response.rb', line 3004 required :model_name, String |
#type ⇒ Symbol, :custom
OpenAI-compatible chat completions API (bring your own endpoint and key).
3010 |
# File 'lib/revox/models/call_search_response.rb', line 3010 required :type, const: :custom |
Instance Method Details
#to_hash ⇒ {
2546 |
# File 'sig/revox/models/call_search_response.rbs', line 2546
def to_hash: -> {
|