Class: Revox::Models::CampaignCreateParams::Contact

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/campaign_create_params.rb,
sig/revox/models/campaign_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(assistant_id:, contacts:, name:, call_retry_config: nil, from_phone_number: nil, max_concurrent_calls: nil, request_options: {}) ⇒ Contact

Some parameter documentations has been truncated, see Revox::Models::CampaignCreateParams for more details.

Parameters:

  • assistant_id (String)

    The ID of the assistant to use

  • contacts (Array<Revox::Models::CampaignCreateParams::Contact>)

    The list of contacts to call

  • name (String)

    The name of the campaign

  • call_retry_config (Revox::Models::CampaignCreateParams::CallRetryConfig) (defaults to: nil)

    Override retry configuration for calls in this campaign. If not provided, uses t

  • from_phone_number (String) (defaults to: nil)

    The phone number to use for outbound calls (E.164 format, e.g., +1234567890)

  • max_concurrent_calls (Float) (defaults to: nil)

    Maximum number of concurrent calls allowed for this campaign

  • request_options (Revox::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})
  • prompt_variables: (top)
  • to_phone_number: (String)


65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/revox/models/campaign_create_params.rb', line 65

class Contact < Revox::Internal::Type::BaseModel
  # @!attribute prompt_variables
  #
  #   @return [Object]
  required :prompt_variables, Revox::Internal::Type::Unknown

  # @!attribute to_phone_number
  #
  #   @return [String]
  required :to_phone_number, String

  # @!method initialize(prompt_variables:, to_phone_number:)
  #   @param prompt_variables [Object]
  #   @param to_phone_number [String]
end

Instance Attribute Details

#prompt_variablesObject

Parameters:

  • value (top)

Returns:

  • (Object)


69
# File 'lib/revox/models/campaign_create_params.rb', line 69

required :prompt_variables, Revox::Internal::Type::Unknown

#to_phone_numberString

Parameters:

  • value (String)

Returns:

  • (String)


74
# File 'lib/revox/models/campaign_create_params.rb', line 74

required :to_phone_number, String

Instance Method Details

#to_hash{ prompt_variables: top, to_phone_number: String }

Returns:

  • ({ prompt_variables: top, to_phone_number: String })


67
# File 'sig/revox/models/campaign_create_params.rbs', line 67

def to_hash: -> { prompt_variables: top, to_phone_number: String }