Class: Revox::Models::CampaignGetRowsResponse::Row::Call

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/campaign_get_rows_response.rb,
sig/revox/models/campaign_get_rows_response.rbs

Overview

See Also:

  • Revox::Models::CampaignGetRowsResponse::Row#call

Defined Under Namespace

Modules: Direction, LlmModel, Outcome, Status Classes: Assignee, Assistant, CallAttempt, CallRetryConfig, Campaign, Contact, LastCallAttempt

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company:, email:, first_name:, last_name:) ⇒ Object

Magic contact variables (prospect identity) extracted from the call's input data and transcript.

Parameters:

  • company (String, nil)
  • email (String, nil)
  • first_name (String, nil)
  • last_name (String, nil)


# File 'lib/revox/models/campaign_get_rows_response.rb', line 227

Instance Attribute Details

#assigneeRevox::Models::CampaignGetRowsResponse::Row::Call::Assignee?

The team member responsible for following up on this call.



69
# File 'lib/revox/models/campaign_get_rows_response.rb', line 69

required :assignee, -> { Revox::Models::CampaignGetRowsResponse::Row::Call::Assignee }, nil?: true

#assistantRevox::Models::CampaignGetRowsResponse::Row::Call::Assistant?



74
# File 'lib/revox/models/campaign_get_rows_response.rb', line 74

required :assistant, -> { Revox::Models::CampaignGetRowsResponse::Row::Call::Assistant }, nil?: true

#call_attemptsArray<Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt>

All call attempts for this call order, ordered by most recent first.



80
81
# File 'lib/revox/models/campaign_get_rows_response.rb', line 80

required :call_attempts,
-> { Revox::Internal::Type::ArrayOf[Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt] }

#call_retry_configRevox::Models::CampaignGetRowsResponse::Row::Call::CallRetryConfig?

Configuration for call retry behavior including time windows, delays, and max iterations. If not provided, defaults will be used.



88
89
90
# File 'lib/revox/models/campaign_get_rows_response.rb', line 88

required :call_retry_config,
-> { Revox::Models::CampaignGetRowsResponse::Row::Call::CallRetryConfig },
nil?: true

#calls_countFloat

The number of call attempts made.

Parameters:

  • value (Float)

Returns:

  • (Float)


96
# File 'lib/revox/models/campaign_get_rows_response.rb', line 96

required :calls_count, Float

#campaignRevox::Models::CampaignGetRowsResponse::Row::Call::Campaign?



101
# File 'lib/revox/models/campaign_get_rows_response.rb', line 101

required :campaign, -> { Revox::Models::CampaignGetRowsResponse::Row::Call::Campaign }, nil?: true

#contactRevox::Models::CampaignGetRowsResponse::Row::Call::Contact

Magic contact variables (prospect identity) extracted from the call's input data and transcript.



108
# File 'lib/revox/models/campaign_get_rows_response.rb', line 108

required :contact, -> { Revox::Models::CampaignGetRowsResponse::Row::Call::Contact }

#created_atObject

The time the call order was created.

Parameters:

  • value (top)

Returns:

  • (Object)


114
# File 'lib/revox/models/campaign_get_rows_response.rb', line 114

required :created_at, Revox::Internal::Type::Unknown

#directionSymbol, Revox::Models::CampaignGetRowsResponse::Row::Call::Direction

Whether the call is inbound or outbound.

Parameters:

  • value (Revox::Models::CampaignGetRowsResponse::Row::Call::direction)

Returns:



120
# File 'lib/revox/models/campaign_get_rows_response.rb', line 120

required :direction, enum: -> { Revox::Models::CampaignGetRowsResponse::Row::Call::Direction }

#first_sentence_delay_msInteger

Delay in milliseconds before speaking the first sentence. Default: 400.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


126
# File 'lib/revox/models/campaign_get_rows_response.rb', line 126

required :first_sentence_delay_ms, Integer

#follow_up_emailsArray<String>?

Extra notification recipients resolved from the agent prompt's own routing rules, when it defines any. Added to the assistant's configured notification recipients; never replaces them. Null when the prompt defines no routing rules.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


213
# File 'lib/revox/models/campaign_get_rows_response.rb', line 213

optional :follow_up_emails, Revox::Internal::Type::ArrayOf[String], nil?: true

#from_phone_numberString

The phone number that made the call. Formatted in E.164 format. Example: +1234567890

Parameters:

  • value (String)

Returns:

  • (String)


133
# File 'lib/revox/models/campaign_get_rows_response.rb', line 133

required :from_phone_number, String

#idString

The ID of the call.

Parameters:

  • value (String)

Returns:

  • (String)


63
# File 'lib/revox/models/campaign_get_rows_response.rb', line 63

required :id, String

#is_cancelledBoolean

DEPRECATED: Whether the call has been cancelled. This is derived from status. Use status instead.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


140
# File 'lib/revox/models/campaign_get_rows_response.rb', line 140

required :is_cancelled, Revox::Internal::Type::Boolean

#is_completedBoolean

DEPRECATED: Whether the call has completed. This is derived from status. Use status instead.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


147
# File 'lib/revox/models/campaign_get_rows_response.rb', line 147

required :is_completed, Revox::Internal::Type::Boolean

#last_call_attemptRevox::Models::CampaignGetRowsResponse::Row::Call::LastCallAttempt?

This represent a single call attempt. A call attempt is a single call made to the phone number.



154
155
156
# File 'lib/revox/models/campaign_get_rows_response.rb', line 154

required :last_call_attempt,
-> { Revox::Models::CampaignGetRowsResponse::Row::Call::LastCallAttempt },
nil?: true

#llm_modelRevox::Models::CampaignGetRowsResponse::Row::Call::LlmModel::UnionMember0, ...



161
# File 'lib/revox/models/campaign_get_rows_response.rb', line 161

required :llm_model, union: -> { Revox::Models::CampaignGetRowsResponse::Row::Call::LlmModel }

#metadataHash{Symbol=>String}?

Metadata stored with the call.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


167
# File 'lib/revox/models/campaign_get_rows_response.rb', line 167

required :metadata, Revox::Internal::Type::HashOf[String], nil?: true

#organization_idString

The ID of the organization that owns the call.

Parameters:

  • value (String)

Returns:

  • (String)


173
# File 'lib/revox/models/campaign_get_rows_response.rb', line 173

required :organization_id, String

#outcomeSymbol, ...

Business outcome of the call. Null if not computed or no transcript.

Parameters:

  • value (Revox::Models::CampaignGetRowsResponse::Row::Call::outcome, nil)

Returns:



219
# File 'lib/revox/models/campaign_get_rows_response.rb', line 219

optional :outcome, enum: -> { Revox::Models::CampaignGetRowsResponse::Row::Call::Outcome }, nil?: true

#outcome_summaryString?

LLM explanation for the outcome, when outcome was computed from the transcript.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


225
# File 'lib/revox/models/campaign_get_rows_response.rb', line 225

optional :outcome_summary, String, nil?: true

#prompt_variablesHash{Symbol=>String}?

Variables used to interpolate the prompt.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


179
# File 'lib/revox/models/campaign_get_rows_response.rb', line 179

required :prompt_variables, Revox::Internal::Type::HashOf[String], nil?: true

#scheduled_atObject

The time the call order is scheduled to start.

Parameters:

  • value (top)

Returns:

  • (Object)


185
# File 'lib/revox/models/campaign_get_rows_response.rb', line 185

required :scheduled_at, Revox::Internal::Type::Unknown

#statusSymbol, Revox::Models::CampaignGetRowsResponse::Row::Call::Status

The status of the call.

Parameters:

  • value (Revox::Models::CampaignGetRowsResponse::Row::Call::status)

Returns:



191
# File 'lib/revox/models/campaign_get_rows_response.rb', line 191

required :status, enum: -> { Revox::Models::CampaignGetRowsResponse::Row::Call::Status }

#to_phone_numberString

The phone number that received the call. Formatted in E.164 format. Example: +1234567890

Parameters:

  • value (String)

Returns:

  • (String)


198
# File 'lib/revox/models/campaign_get_rows_response.rb', line 198

required :to_phone_number, String

#updated_atObject

The time the call order was last updated (any state change, retry, or analysis result).

Parameters:

  • value (top)

Returns:

  • (Object)


205
# File 'lib/revox/models/campaign_get_rows_response.rb', line 205

required :updated_at, Revox::Internal::Type::Unknown

Instance Method Details

#to_hash{

Returns:

  • ({)


169
# File 'sig/revox/models/campaign_get_rows_response.rbs', line 169

def to_hash: -> {