Class: Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/campaign_get_rows_response.rb,
sig/revox/models/campaign_get_rows_response.rbs

Defined Under Namespace

Modules: DialError, EndReason, EndedBy, Result, Status Classes: PostCallTranscript, SMSLog, Transcript

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, answered_at:, dial_error:, ended_at:, phone_number:, recording_url:, result:, started_at:, status:, assistants_used: nil, end_reason: nil, ended_by: nil, post_call_transcript: nil, sms_log: nil, structured_output: nil, transcript: nil) ⇒ Object

Some parameter documentations has been truncated, see Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt for more details.

This represent a single call attempt. A call attempt is a single call made to the phone number.

Parameters:



# File 'lib/revox/models/campaign_get_rows_response.rb', line 2037

Instance Attribute Details

#answered_atObject

The time the call was answered.

Parameters:

  • value (top)

Returns:

  • (Object)


1929
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1929

required :answered_at, Revox::Internal::Type::Unknown

#assistants_usedArray<String>?

Assistant node ids entered during this attempt, in traversal order.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


1981
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1981

optional :assistants_used, Revox::Internal::Type::ArrayOf[String], nil?: true

#dial_errorSymbol, ...

The SIP error that occurred.

Parameters:

  • value (Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::dial_error, nil)

Returns:



1935
1936
1937
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1935

required :dial_error,
enum: -> { Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::DialError },
nil?: true

#end_reasonSymbol, ...

Reason for ending the call when ended_by is 'agent'. E.g. 'tool_end_call', 'voicemail', 'transfer', 'ivr_no_navigate'.

Parameters:

  • value (Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::end_reason, nil)

Returns:



1988
1989
1990
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1988

optional :end_reason,
enum: -> { Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::EndReason },
nil?: true

#ended_atObject

The time the call ended.

Parameters:

  • value (top)

Returns:

  • (Object)


1943
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1943

required :ended_at, Revox::Internal::Type::Unknown

#ended_bySymbol, ...

Who ended the call: 'agent' (AI agent), 'user' (caller/callee hung up), or 'system' (e.g. max duration limit).

Parameters:

  • value (Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::ended_by, nil)

Returns:



1997
1998
1999
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1997

optional :ended_by,
enum: -> { Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::EndedBy },
nil?: true

#idString

The ID of the call attempt.

Parameters:

  • value (String)

Returns:

  • (String)


1923
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1923

required :id, String

#phone_numberString

The phone number that was called. Formatted in E.164 format. Example: +1234567890

Parameters:

  • value (String)

Returns:

  • (String)


1950
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1950

required :phone_number, String

#post_call_transcriptArray<Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::PostCallTranscript>?

Higher-quality transcript generated after the call via Soniox async STT. Null until generated or when no recording is available.



2006
2007
2008
# File 'lib/revox/models/campaign_get_rows_response.rb', line 2006

optional :post_call_transcript,
-> { Revox::Internal::Type::ArrayOf[Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::PostCallTranscript] },
nil?: true

#recording_urlString?

The URL of the audio recording of the call.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1956
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1956

required :recording_url, String, nil?: true

#resultSymbol, ...

Parameters:

  • value (Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::result, nil)

Returns:



1961
1962
1963
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1961

required :result,
enum: -> { Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::Result },
nil?: true

#sms_logArray<Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::SMSLog>?

Automatic SMS sent after the call (voicemail and after-call), ordered oldest first. The in-call send_sms is excluded — it already appears in the transcript as a tool call.



2016
2017
2018
# File 'lib/revox/models/campaign_get_rows_response.rb', line 2016

optional :sms_log,
-> { Revox::Internal::Type::ArrayOf[Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::SMSLog] },
nil?: true

#started_atObject

The time the call started.

Parameters:

  • value (top)

Returns:

  • (Object)


1969
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1969

required :started_at, Revox::Internal::Type::Unknown

#statusSymbol, Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::Status

The status of the call attempt.

Parameters:

  • value (Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::status)

Returns:



1975
# File 'lib/revox/models/campaign_get_rows_response.rb', line 1975

required :status, enum: -> { Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::Status }

#structured_outputHash{Symbol=>Object}?

The data extracted from the call, using the structured output config from the parent call object.

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:

  • (Hash{Symbol=>Object}, nil)


2025
2026
2027
# File 'lib/revox/models/campaign_get_rows_response.rb', line 2025

optional :structured_output,
Revox::Internal::Type::HashOf[Revox::Internal::Type::Unknown],
nil?: true

#transcriptArray<Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::Transcript>?

The live transcript of the call, built in real time.



2033
2034
2035
# File 'lib/revox/models/campaign_get_rows_response.rb', line 2033

optional :transcript,
-> { Revox::Internal::Type::ArrayOf[Revox::Models::CampaignGetRowsResponse::Row::Call::CallAttempt::Transcript] },
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/revox/models/campaign_get_rows_response.rb', line 2092

Instance Method Details

#to_hash{

Returns:

  • ({)


1615
# File 'sig/revox/models/campaign_get_rows_response.rbs', line 1615

def to_hash: -> {