Module: Revox::Models::CampaignLaunchResponse::Session::InFlightCall::Assistant::CallRetryConfig::AllowedDay

Extended by:
Internal::Type::Enum
Defined in:
lib/revox/models/campaign_launch_response.rb,
sig/revox/models/campaign_launch_response.rbs

Constant Summary collapse

MONDAY =

Returns:

:monday
TUESDAY =

Returns:

:tuesday
WEDNESDAY =

Returns:

:wednesday
THURSDAY =

Returns:

:thursday
FRIDAY =

Returns:

:friday
SATURDAY =

Returns:

:saturday
SUNDAY =

Returns:

:sunday

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(allowed_days:, call_twice_in_a_row:, calling_windows:, max_retry_attempts:, timezone: nil) ⇒ Object

Some parameter documentations has been truncated, see Revox::Models::CampaignLaunchResponse::Session::InFlightCall::Assistant::CallRetryConfig for more details.

Configuration for call retry behavior including time windows, delays, and max iterations. If not provided, defaults will be used.

Parameters:

  • Days of the week when calls are allowed, in the recipient's timezone. Default: M

  • If true and max_retry_attempts >= 2, attempt #2 fires immediately (skipping retr

  • Maximum number of call retry attempts. Default: 3.

  • (defaults to: nil)

    Optional IANA timezone identifier to override the automatic timezone detection f



1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
# File 'lib/revox/models/campaign_launch_response.rb', line 1010

module AllowedDay
  extend Revox::Internal::Type::Enum

  MONDAY = :monday
  TUESDAY = :tuesday
  WEDNESDAY = :wednesday
  THURSDAY = :thursday
  FRIDAY = :friday
  SATURDAY = :saturday
  SUNDAY = :sunday

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values ⇒ ::Array[Revox::Models::CampaignLaunchResponse::Session::InFlightCall::Assistant::CallRetryConfig::allowed_day]

Returns:



702
# File 'sig/revox/models/campaign_launch_response.rbs', line 702

def self?.values: -> ::Array[Revox::Models::CampaignLaunchResponse::Session::InFlightCall::Assistant::CallRetryConfig::allowed_day]