Class: Revox::Models::CampaignRetrieveResponse::Campaign::Assistant::Slack::Channel

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/campaign_retrieve_response.rb,
sig/revox/models/campaign_retrieve_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channels:, connection_id:, outcomes:, template: nil) ⇒ Channel

Some parameter documentations has been truncated, see Revox::Models::CampaignRetrieveResponse::Campaign::Assistant::Slack for more details.

{{call_

Parameters:



1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
# File 'lib/revox/models/campaign_retrieve_response.rb', line 1335

class Channel < Revox::Internal::Type::BaseModel
  # @!attribute id
  #   The Slack channel ID (e.g. 'C01234567').
  #
  #   @return [String]
  required :id, String

  # @!attribute name
  #   Human-readable Slack channel name, cached for display in the UI and given to the
  #   LLM when the agent prompt routes by channel name.
  #
  #   @return [String, nil]
  optional :name, String, nil?: true

  # @!method initialize(id:, name: nil)
  #   Some parameter documentations has been truncated, see
  #   {Revox::Models::CampaignRetrieveResponse::Campaign::Assistant::Slack::Channel}
  #   for more details.
  #
  #   @param id [String] The Slack channel ID (e.g. 'C01234567').
  #
  #   @param name [String, nil] Human-readable Slack channel name, cached for display in the UI and given to the
end

Instance Attribute Details

#idString

The Slack channel ID (e.g. 'C01234567').

Parameters:

  • value (String)

Returns:

  • (String)


1340
# File 'lib/revox/models/campaign_retrieve_response.rb', line 1340

required :id, String

#nameString?

Human-readable Slack channel name, cached for display in the UI and given to the LLM when the agent prompt routes by channel name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1347
# File 'lib/revox/models/campaign_retrieve_response.rb', line 1347

optional :name, String, nil?: true

Instance Method Details

#to_hash{ id: String, name: String? }

Returns:

  • ({ id: String, name: String? })


1053
# File 'sig/revox/models/campaign_retrieve_response.rbs', line 1053

def to_hash: -> { id: String, name: String? }