Class: Revox::Models::CampaignUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::CampaignUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/revox/models/campaign_update_params.rb,
sig/revox/models/campaign_update_params.rbs
Overview
Defined Under Namespace
Classes: CallRetryConfig
Instance Attribute Summary collapse
-
#call_retry_config ⇒ Revox::Models::CampaignUpdateParams::CallRetryConfig?
Configuration for call retry behavior including time windows, delays, and max iterations.
-
#from_phone_number ⇒ String?
The phone number to use for outbound calls.
- #id ⇒ String
-
#max_concurrent_calls ⇒ Float?
Maximum concurrent calls.
-
#name ⇒ String?
Campaign display name.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
29 |
# File 'sig/revox/models/campaign_update_params.rbs', line 29
def initialize: (
|
Instance Attribute Details
#call_retry_config ⇒ Revox::Models::CampaignUpdateParams::CallRetryConfig?
Configuration for call retry behavior including time windows, delays, and max iterations. If not provided, defaults will be used.
20 |
# File 'lib/revox/models/campaign_update_params.rb', line 20 optional :call_retry_config, -> { Revox::CampaignUpdateParams::CallRetryConfig }, nil?: true |
#from_phone_number ⇒ String?
The phone number to use for outbound calls. Editable after launch; applied to the campaign's calls that have not completed yet.
27 |
# File 'lib/revox/models/campaign_update_params.rb', line 27 optional :from_phone_number, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/revox/models/campaign_update_params.rb', line 13 required :id, String |
#max_concurrent_calls ⇒ Float?
Maximum concurrent calls. Editable after launch.
33 |
# File 'lib/revox/models/campaign_update_params.rb', line 33 optional :max_concurrent_calls, Float, nil?: true |
#name ⇒ String?
Campaign display name
39 |
# File 'lib/revox/models/campaign_update_params.rb', line 39 optional :name, String |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/revox/models/campaign_update_params.rbs', line 38
def to_hash: -> {
|