Class: Revox::Models::CampaignUpdateParams::CallRetryConfig::CallingWindow

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/campaign_update_params.rb,
sig/revox/models/campaign_update_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(calling_window_end_time:, calling_window_start_time:, retry_delay_seconds:) ⇒ Object

Some parameter documentations has been truncated, see Revox::Models::CampaignUpdateParams::CallRetryConfig::CallingWindow for more details.

Parameters:

  • calling_window_end_time (String)

    End time for the calling window in the recipient's timezone (or timezone_overrid

  • calling_window_start_time (String)

    Start time for the calling window in the recipient's timezone (or timezone_overr

  • retry_delay_seconds (Integer)

    Delay between retry attempts in seconds. 0 retries as soon as the calling window



# File 'lib/revox/models/campaign_update_params.rb', line 151

Instance Attribute Details

#calling_window_end_timeString

End time for the calling window in the recipient's timezone (or timezone_override if provided). Format: 'HH:mm' (24-hour) or 'H:mma' (12-hour). Examples: '17:00', '6pm'. Default: '18:00'.

Parameters:

  • value (String)

Returns:

  • (String)


134
# File 'lib/revox/models/campaign_update_params.rb', line 134

required :calling_window_end_time, String

#calling_window_start_timeString

Start time for the calling window in the recipient's timezone (or timezone_override if provided). Format: 'HH:mm' (24-hour) or 'H:mma' (12-hour). Examples: '09:00', '10am'. Default: '10:00'.

Parameters:

  • value (String)

Returns:

  • (String)


142
# File 'lib/revox/models/campaign_update_params.rb', line 142

required :calling_window_start_time, String

#retry_delay_secondsInteger

Delay between retry attempts in seconds. 0 retries as soon as the calling window allows. Default: 7200 (2 hours).

Parameters:

  • value (Integer)

Returns:

  • (Integer)


149
# File 'lib/revox/models/campaign_update_params.rb', line 149

required :retry_delay_seconds, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


126
# File 'sig/revox/models/campaign_update_params.rbs', line 126

def to_hash: -> {