Class: Revox::Models::PhoneNumberUpdateResponse::PhoneNumber::InboundAssistant::Slack::Channel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::PhoneNumberUpdateResponse::PhoneNumber::InboundAssistant::Slack::Channel
- Defined in:
- lib/revox/models/phone_number_update_response.rb,
sig/revox/models/phone_number_update_response.rbs
Instance Attribute Summary collapse
-
#id ⇒ String
The Slack channel ID (e.g. 'C01234567').
-
#name ⇒ String?
Human-readable Slack channel name, cached for display in the UI and given to the LLM when the agent prompt routes by channel name.
Instance Method Summary collapse
-
#initialize(channels:, connection_id:, outcomes:, template: nil) ⇒ Channel
constructor
Some parameter documentations has been truncated, see Revox::Models::PhoneNumberUpdateResponse::PhoneNumber::InboundAssistant::Slack for more details.
- #to_hash ⇒ { id: String, name: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channels:, connection_id:, outcomes:, template: nil) ⇒ Channel
Some parameter documentations has been truncated, see Revox::Models::PhoneNumberUpdateResponse::PhoneNumber::InboundAssistant::Slack for more details.
{{call_
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 |
# File 'lib/revox/models/phone_number_update_response.rb', line 1311 class Channel < Revox::Internal::Type::BaseModel # @!attribute id # The Slack channel ID (e.g. 'C01234567'). # # @return [String] required :id, String # @!attribute name # Human-readable Slack channel name, cached for display in the UI and given to the # LLM when the agent prompt routes by channel name. # # @return [String, nil] optional :name, String, nil?: true # @!method initialize(id:, name: nil) # Some parameter documentations has been truncated, see # {Revox::Models::PhoneNumberUpdateResponse::PhoneNumber::InboundAssistant::Slack::Channel} # for more details. # # @param id [String] The Slack channel ID (e.g. 'C01234567'). # # @param name [String, nil] Human-readable Slack channel name, cached for display in the UI and given to the end |
Instance Attribute Details
#id ⇒ String
The Slack channel ID (e.g. 'C01234567').
1316 |
# File 'lib/revox/models/phone_number_update_response.rb', line 1316 required :id, String |
#name ⇒ String?
Human-readable Slack channel name, cached for display in the UI and given to the LLM when the agent prompt routes by channel name.
1323 |
# File 'lib/revox/models/phone_number_update_response.rb', line 1323 optional :name, String, nil?: true |
Instance Method Details
#to_hash ⇒ { id: String, name: String? }
1013 |
# File 'sig/revox/models/phone_number_update_response.rbs', line 1013
def to_hash: -> { id: String, name: String? }
|