Class: Revox::Models::CallCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/revox/models/call_create_params.rb,
sig/revox/models/call_create_params.rbs

Overview

See Also:

  • Revox::Resources::Call#create

Defined Under Namespace

Modules: ScheduledAt Classes: Assistant, Concurrency

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(key:, max:) ⇒ Object

Limit the number of concurrent calls for a given concurrency key.

Parameters:

  • key (String)

    The key for which you want to limit the number of concurrent calls.

  • max (Float)

    The maximum number of concurrent calls to allow for the given concurrency key.



# File 'lib/revox/models/call_create_params.rb', line 1622

Instance Attribute Details

#assistantRevox::Models::CallCreateParams::Assistant?

You can provide a custom assistant configuration here. If you don't provide an assistant_id, this assistant object will be used for this call.



21
# File 'lib/revox/models/call_create_params.rb', line 21

optional :assistant, -> { Revox::CallCreateParams::Assistant }

#assistant_idString?

The ID of the assistant to use for this call.

Parameters:

  • (String)

Returns:

  • (String, nil)


27
# File 'lib/revox/models/call_create_params.rb', line 27

optional :assistant_id, String

#concurrencyRevox::Models::CallCreateParams::Concurrency?

Limit the number of concurrent calls for a given concurrency key.



33
# File 'lib/revox/models/call_create_params.rb', line 33

optional :concurrency, -> { Revox::CallCreateParams::Concurrency }

#force_nowBoolean?

The prompt to use for the call. This will be given to the LLM (gpt-4.1)

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


39
# File 'lib/revox/models/call_create_params.rb', line 39

optional :force_now, Revox::Internal::Type::Boolean

#from_phone_numberString?

The phone number to use for making the call (e.g., +1234567890). If not provided, uses the default trunk.

Parameters:

  • (String)

Returns:

  • (String, nil)


46
# File 'lib/revox/models/call_create_params.rb', line 46

optional :from_phone_number, String

#metadataHash{Symbol=>String}?

Metadata to store with the call.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


52
# File 'lib/revox/models/call_create_params.rb', line 52

optional :metadata, Revox::Internal::Type::HashOf[String]

#phone_numberString

The phone number to call in the E.164 format. Example: +1234567890

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/revox/models/call_create_params.rb', line 14

required :phone_number, String

#prompt_variablesHash{Symbol=>String}?

Variables to interpolate into the prompt. Wether you use an assistant_id or an assistant object, this will be used to interpolate the variables into the prompt.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


60
# File 'lib/revox/models/call_create_params.rb', line 60

optional :prompt_variables, Revox::Internal::Type::HashOf[String]

#scheduled_atTime, ...

Schedule the call to start at a specific date and time (ISO 8601 format). If not provided, the call will start immediately.

Returns:

  • (Time, Object, nil)


67
# File 'lib/revox/models/call_create_params.rb', line 67

optional :scheduled_at, union: -> { Revox::CallCreateParams::ScheduledAt }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/revox/models/call_create_params.rb', line 1603

Instance Method Details

#to_hash{

Returns:

  • ({)


74
# File 'sig/revox/models/call_create_params.rbs', line 74

def to_hash: -> {