Class: Revox::Models::CallCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::CallCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/revox/models/call_create_params.rb,
sig/revox/models/call_create_params.rbs
Overview
Defined Under Namespace
Modules: ScheduledAt Classes: Assistant, Concurrency
Instance Attribute Summary collapse
-
#assistant ⇒ Revox::Models::CallCreateParams::Assistant?
You can provide a custom assistant configuration here.
-
#assistant_id ⇒ String?
The ID of the assistant to use for this call.
-
#concurrency ⇒ Revox::Models::CallCreateParams::Concurrency?
Limit the number of concurrent calls for a given concurrency key.
-
#force_now ⇒ Boolean?
The prompt to use for the call.
-
#from_phone_number ⇒ String?
The phone number to use for making the call (e.g., +1234567890).
-
#metadata ⇒ Hash{Symbol=>String}?
Metadata to store with the call.
-
#phone_number ⇒ String
The phone number to call in the E.164 format.
-
#prompt_variables ⇒ Hash{Symbol=>String}?
Variables to interpolate into the prompt.
-
#scheduled_at ⇒ Time, ...
Schedule the call to start at a specific date and time (ISO 8601 format).
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(key:, max:) ⇒ Object
constructor
Limit the number of concurrent calls for a given concurrency key.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(key:, max:) ⇒ Object
Limit the number of concurrent calls for a given concurrency key.
|
|
# File 'lib/revox/models/call_create_params.rb', line 1622
|
Instance Attribute Details
#assistant ⇒ Revox::Models::CallCreateParams::Assistant?
You can provide a custom assistant configuration here. If you don't provide an assistant_id, this assistant object will be used for this call.
21 |
# File 'lib/revox/models/call_create_params.rb', line 21 optional :assistant, -> { Revox::CallCreateParams::Assistant } |
#assistant_id ⇒ String?
The ID of the assistant to use for this call.
27 |
# File 'lib/revox/models/call_create_params.rb', line 27 optional :assistant_id, String |
#concurrency ⇒ Revox::Models::CallCreateParams::Concurrency?
Limit the number of concurrent calls for a given concurrency key.
33 |
# File 'lib/revox/models/call_create_params.rb', line 33 optional :concurrency, -> { Revox::CallCreateParams::Concurrency } |
#force_now ⇒ Boolean?
The prompt to use for the call. This will be given to the LLM (gpt-4.1)
39 |
# File 'lib/revox/models/call_create_params.rb', line 39 optional :force_now, Revox::Internal::Type::Boolean |
#from_phone_number ⇒ String?
The phone number to use for making the call (e.g., +1234567890). If not provided, uses the default trunk.
46 |
# File 'lib/revox/models/call_create_params.rb', line 46 optional :from_phone_number, String |
#metadata ⇒ Hash{Symbol=>String}?
Metadata to store with the call.
52 |
# File 'lib/revox/models/call_create_params.rb', line 52 optional :metadata, Revox::Internal::Type::HashOf[String] |
#phone_number ⇒ String
The phone number to call in the E.164 format. Example: +1234567890
14 |
# File 'lib/revox/models/call_create_params.rb', line 14 required :phone_number, String |
#prompt_variables ⇒ Hash{Symbol=>String}?
Variables to interpolate into the prompt. Wether you use an assistant_id or an assistant object, this will be used to interpolate the variables into the prompt.
60 |
# File 'lib/revox/models/call_create_params.rb', line 60 optional :prompt_variables, Revox::Internal::Type::HashOf[String] |
#scheduled_at ⇒ Time, ...
Schedule the call to start at a specific date and time (ISO 8601 format). If not provided, the call will start immediately.
67 |
# File 'lib/revox/models/call_create_params.rb', line 67 optional :scheduled_at, union: -> { Revox::CallCreateParams::ScheduledAt } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/revox/models/call_create_params.rb', line 1603
|
Instance Method Details
#to_hash ⇒ {
74 |
# File 'sig/revox/models/call_create_params.rbs', line 74
def to_hash: -> {
|