Class: Revox::Models::CallCreateParams::Assistant::Zoho::FieldMapping
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::CallCreateParams::Assistant::Zoho::FieldMapping
- Defined in:
- lib/revox/models/call_create_params.rb,
sig/revox/models/call_create_params.rbs
Instance Attribute Summary collapse
-
#source ⇒ String
Source key to read from the call: a structured_output field name, falling back to a prompt variable of the same name.
-
#zoho_field ⇒ String
Destination Zoho field API name on the upserted record (e.g. 'Email', 'Company', or a custom 'Budget__c').
Instance Method Summary collapse
-
#initialize(connection_id:, field_mapping:, log_call_activity:, module_:, outcomes:, template: nil) ⇒ FieldMapping
constructor
Some parameter documentations has been truncated, see Revox::Models::CallCreateParams::Assistant::Zoho for more details.
- #to_hash ⇒ { source: String, zoho_field: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_id:, field_mapping:, log_call_activity:, module_:, outcomes:, template: nil) ⇒ FieldMapping
Some parameter documentations has been truncated, see Revox::Models::CallCreateParams::Assistant::Zoho for more details.
Zoho CRM integration config. When set, upserts the prospect (keyed on phone) into the chosen module and attaches a Note with the call summary after a call ends with one of the configured outcomes.
1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 |
# File 'lib/revox/models/call_create_params.rb', line 1566 class FieldMapping < Revox::Internal::Type::BaseModel # @!attribute source # Source key to read from the call: a structured_output field name, falling back # to a prompt variable of the same name. # # @return [String] required :source, String # @!attribute zoho_field # Destination Zoho field API name on the upserted record (e.g. 'Email', 'Company', # or a custom 'Budget\_\_c'). # # @return [String] required :zoho_field, String # @!method initialize(source:, zoho_field:) # Some parameter documentations has been truncated, see # {Revox::Models::CallCreateParams::Assistant::Zoho::FieldMapping} for more # details. # # @param source [String] Source key to read from the call: a structured_output field name, falling back t # # @param zoho_field [String] Destination Zoho field API name on the upserted record (e.g. 'Email', 'Company', end |
Instance Attribute Details
#source ⇒ String
Source key to read from the call: a structured_output field name, falling back to a prompt variable of the same name.
1572 |
# File 'lib/revox/models/call_create_params.rb', line 1572 required :source, String |
#zoho_field ⇒ String
Destination Zoho field API name on the upserted record (e.g. 'Email', 'Company', or a custom 'Budget__c').
1579 |
# File 'lib/revox/models/call_create_params.rb', line 1579 required :zoho_field, String |
Instance Method Details
#to_hash ⇒ { source: String, zoho_field: String }
1294 |
# File 'sig/revox/models/call_create_params.rbs', line 1294
def to_hash: -> { source: String, zoho_field: String }
|