Class: Revox::Models::CallCreateParams::Concurrency

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/call_create_params.rb,
sig/revox/models/call_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeConcurrency

Returns a new instance of Concurrency.

Parameters:

  • key: (String)
  • max: (Float)


1331
# File 'sig/revox/models/call_create_params.rbs', line 1331

def initialize: (key: String, max: Float) -> void

Instance Attribute Details

#keyString

The key for which you want to limit the number of concurrent calls.

Parameters:

  • value (String)

Returns:

  • (String)


1614
# File 'lib/revox/models/call_create_params.rb', line 1614

required :key, String

#maxFloat

The maximum number of concurrent calls to allow for the given concurrency key.

Parameters:

  • value (Float)

Returns:

  • (Float)


1620
# File 'lib/revox/models/call_create_params.rb', line 1620

required :max, Float

Instance Method Details

#to_hash{ key: String, max: Float }

Returns:

  • ({ key: String, max: Float })


1333
# File 'sig/revox/models/call_create_params.rbs', line 1333

def to_hash: -> { key: String, max: Float }