Class: Revox::Models::CallRetrieveResponse::Call

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/call_retrieve_response.rb,
sig/revox/models/call_retrieve_response.rbs

Overview

See Also:

  • Revox::Models::CallRetrieveResponse#call

Defined Under Namespace

Modules: Direction, LlmModel, Outcome, Status Classes: Assignee, Assistant, CallAttempt, CallRetryConfig, Campaign, Contact, LastCallAttempt

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company:, email:, first_name:, last_name:) ⇒ Object

Magic contact variables (prospect identity) extracted from the call's input data and transcript.

Parameters:

  • company (String, nil)
  • email (String, nil)
  • first_name (String, nil)
  • last_name (String, nil)


# File 'lib/revox/models/call_retrieve_response.rb', line 178

Instance Attribute Details

#assigneeRevox::Models::CallRetrieveResponse::Call::Assignee?

The team member responsible for following up on this call.



32
# File 'lib/revox/models/call_retrieve_response.rb', line 32

required :assignee, -> { Revox::Models::CallRetrieveResponse::Call::Assignee }, nil?: true

#assistantRevox::Models::CallRetrieveResponse::Call::Assistant?



37
# File 'lib/revox/models/call_retrieve_response.rb', line 37

required :assistant, -> { Revox::Models::CallRetrieveResponse::Call::Assistant }, nil?: true

#call_attemptsArray<Revox::Models::CallRetrieveResponse::Call::CallAttempt>

All call attempts for this call order, ordered by most recent first.



43
44
# File 'lib/revox/models/call_retrieve_response.rb', line 43

required :call_attempts,
-> { Revox::Internal::Type::ArrayOf[Revox::Models::CallRetrieveResponse::Call::CallAttempt] }

#call_retry_configRevox::Models::CallRetrieveResponse::Call::CallRetryConfig?

Configuration for call retry behavior including time windows, delays, and max iterations. If not provided, defaults will be used.



51
# File 'lib/revox/models/call_retrieve_response.rb', line 51

required :call_retry_config, -> { Revox::Models::CallRetrieveResponse::Call::CallRetryConfig }, nil?: true

#calls_countFloat

The number of call attempts made.

Parameters:

  • value (Float)

Returns:

  • (Float)


57
# File 'lib/revox/models/call_retrieve_response.rb', line 57

required :calls_count, Float

#campaignRevox::Models::CallRetrieveResponse::Call::Campaign?



62
# File 'lib/revox/models/call_retrieve_response.rb', line 62

required :campaign, -> { Revox::Models::CallRetrieveResponse::Call::Campaign }, nil?: true

#contactRevox::Models::CallRetrieveResponse::Call::Contact

Magic contact variables (prospect identity) extracted from the call's input data and transcript.



69
# File 'lib/revox/models/call_retrieve_response.rb', line 69

required :contact, -> { Revox::Models::CallRetrieveResponse::Call::Contact }

#created_atObject

The time the call order was created.

Parameters:

  • value (top)

Returns:

  • (Object)


75
# File 'lib/revox/models/call_retrieve_response.rb', line 75

required :created_at, Revox::Internal::Type::Unknown

#directionSymbol, Revox::Models::CallRetrieveResponse::Call::Direction

Whether the call is inbound or outbound.

Parameters:

  • value (Revox::Models::CallRetrieveResponse::Call::direction)

Returns:



81
# File 'lib/revox/models/call_retrieve_response.rb', line 81

required :direction, enum: -> { Revox::Models::CallRetrieveResponse::Call::Direction }

#first_sentence_delay_msInteger

Delay in milliseconds before speaking the first sentence. Default: 400.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


87
# File 'lib/revox/models/call_retrieve_response.rb', line 87

required :first_sentence_delay_ms, Integer

#from_phone_numberString

The phone number that made the call. Formatted in E.164 format. Example: +1234567890

Parameters:

  • value (String)

Returns:

  • (String)


94
# File 'lib/revox/models/call_retrieve_response.rb', line 94

required :from_phone_number, String

#idString

The ID of the call.

Parameters:

  • value (String)

Returns:

  • (String)


26
# File 'lib/revox/models/call_retrieve_response.rb', line 26

required :id, String

#is_cancelledBoolean

DEPRECATED: Whether the call has been cancelled. This is derived from status. Use status instead.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


101
# File 'lib/revox/models/call_retrieve_response.rb', line 101

required :is_cancelled, Revox::Internal::Type::Boolean

#is_completedBoolean

DEPRECATED: Whether the call has completed. This is derived from status. Use status instead.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


108
# File 'lib/revox/models/call_retrieve_response.rb', line 108

required :is_completed, Revox::Internal::Type::Boolean

#last_call_attemptRevox::Models::CallRetrieveResponse::Call::LastCallAttempt?

This represent a single call attempt. A call attempt is a single call made to the phone number.



115
# File 'lib/revox/models/call_retrieve_response.rb', line 115

required :last_call_attempt, -> { Revox::Models::CallRetrieveResponse::Call::LastCallAttempt }, nil?: true

#llm_modelRevox::Models::CallRetrieveResponse::Call::LlmModel::UnionMember0, ...



120
# File 'lib/revox/models/call_retrieve_response.rb', line 120

required :llm_model, union: -> { Revox::Models::CallRetrieveResponse::Call::LlmModel }

#metadataHash{Symbol=>String}?

Metadata stored with the call.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


126
# File 'lib/revox/models/call_retrieve_response.rb', line 126

required :metadata, Revox::Internal::Type::HashOf[String], nil?: true

#organization_idString

The ID of the organization that owns the call.

Parameters:

  • value (String)

Returns:

  • (String)


132
# File 'lib/revox/models/call_retrieve_response.rb', line 132

required :organization_id, String

#outcomeSymbol, ...

Business outcome of the call. Null if not computed or no transcript.

Parameters:

  • value (Revox::Models::CallRetrieveResponse::Call::outcome, nil)

Returns:



170
# File 'lib/revox/models/call_retrieve_response.rb', line 170

optional :outcome, enum: -> { Revox::Models::CallRetrieveResponse::Call::Outcome }, nil?: true

#outcome_summaryString?

LLM explanation for the outcome, when outcome was computed from the transcript.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


176
# File 'lib/revox/models/call_retrieve_response.rb', line 176

optional :outcome_summary, String, nil?: true

#prompt_variablesHash{Symbol=>String}?

Variables used to interpolate the prompt.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


138
# File 'lib/revox/models/call_retrieve_response.rb', line 138

required :prompt_variables, Revox::Internal::Type::HashOf[String], nil?: true

#scheduled_atObject

The time the call order is scheduled to start.

Parameters:

  • value (top)

Returns:

  • (Object)


144
# File 'lib/revox/models/call_retrieve_response.rb', line 144

required :scheduled_at, Revox::Internal::Type::Unknown

#statusSymbol, Revox::Models::CallRetrieveResponse::Call::Status

The status of the call.

Parameters:

  • value (Revox::Models::CallRetrieveResponse::Call::status)

Returns:



150
# File 'lib/revox/models/call_retrieve_response.rb', line 150

required :status, enum: -> { Revox::Models::CallRetrieveResponse::Call::Status }

#to_phone_numberString

The phone number that received the call. Formatted in E.164 format. Example: +1234567890

Parameters:

  • value (String)

Returns:

  • (String)


157
# File 'lib/revox/models/call_retrieve_response.rb', line 157

required :to_phone_number, String

#updated_atObject

The time the call order was last updated (any state change, retry, or analysis result).

Parameters:

  • value (top)

Returns:

  • (Object)


164
# File 'lib/revox/models/call_retrieve_response.rb', line 164

required :updated_at, Revox::Internal::Type::Unknown

Instance Method Details

#to_hash{

Returns:

  • ({)


121
# File 'sig/revox/models/call_retrieve_response.rbs', line 121

def to_hash: -> {