Class: Revox::Models::CampaignCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::CampaignCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/revox/models/campaign_create_params.rb,
sig/revox/models/campaign_create_params.rbs
Overview
Defined Under Namespace
Classes: CallRetryConfig, Contact
Instance Attribute Summary collapse
-
#assistant_id ⇒ String
The ID of the assistant to use.
-
#call_retry_config ⇒ Revox::Models::CampaignCreateParams::CallRetryConfig?
Override retry configuration for calls in this campaign.
-
#contacts ⇒ Array<Revox::Models::CampaignCreateParams::Contact>
The list of contacts to call.
-
#from_phone_number ⇒ String?
The phone number to use for outbound calls (E.164 format, e.g., +1234567890).
-
#max_concurrent_calls ⇒ Float?
Maximum number of concurrent calls allowed for this campaign.
-
#name ⇒ String
The name of the campaign.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(prompt_variables:, to_phone_number:) ⇒ Object
|
|
# File 'lib/revox/models/campaign_create_params.rb', line 76
|
Instance Attribute Details
#assistant_id ⇒ String
The ID of the assistant to use
14 |
# File 'lib/revox/models/campaign_create_params.rb', line 14 required :assistant_id, String |
#call_retry_config ⇒ Revox::Models::CampaignCreateParams::CallRetryConfig?
Override retry configuration for calls in this campaign. If not provided, uses the assistant's retry config.
33 |
# File 'lib/revox/models/campaign_create_params.rb', line 33 optional :call_retry_config, -> { Revox::CampaignCreateParams::CallRetryConfig } |
#contacts ⇒ Array<Revox::Models::CampaignCreateParams::Contact>
The list of contacts to call
20 |
# File 'lib/revox/models/campaign_create_params.rb', line 20 required :contacts, -> { Revox::Internal::Type::ArrayOf[Revox::CampaignCreateParams::Contact] } |
#from_phone_number ⇒ String?
The phone number to use for outbound calls (E.164 format, e.g., +1234567890)
39 |
# File 'lib/revox/models/campaign_create_params.rb', line 39 optional :from_phone_number, String |
#max_concurrent_calls ⇒ Float?
Maximum number of concurrent calls allowed for this campaign
45 |
# File 'lib/revox/models/campaign_create_params.rb', line 45 optional :max_concurrent_calls, Float |
#name ⇒ String
The name of the campaign
26 |
# File 'lib/revox/models/campaign_create_params.rb', line 26 required :name, String |
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/revox/models/campaign_create_params.rbs', line 48
def to_hash: -> {
|