Class: Revox::Models::CampaignCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/revox/models/campaign_create_params.rb,
sig/revox/models/campaign_create_params.rbs

Overview

See Also:

  • Revox::Resources::Campaigns#create

Defined Under Namespace

Modules: ScheduledAt, Type Classes: CallRetryConfig, Contact

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(calling_window_end_time:, calling_window_start_time:, retry_delay_seconds:) ⇒ Object

Some parameter documentations has been truncated, see Revox::Models::CampaignCreateParams::CallRetryConfig::CallingWindow for more details.

Parameters:

  • calling_window_end_time (String)

    End time for the calling window in the recipient's timezone (or timezone_overrid

  • calling_window_start_time (String)

    Start time for the calling window in the recipient's timezone (or timezone_overr

  • retry_delay_seconds (Integer)

    Delay between retry attempts in seconds. Default: 7200 (2 hours).



# File 'lib/revox/models/campaign_create_params.rb', line 102

Instance Attribute Details

#assistant_idString

The ID of the assistant to use

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/revox/models/campaign_create_params.rb', line 14

required :assistant_id, String

#call_retry_configRevox::Models::CampaignCreateParams::CallRetryConfig?

Override retry configuration for calls in this campaign. If not provided, uses the assistant's retry config.



46
# File 'lib/revox/models/campaign_create_params.rb', line 46

optional :call_retry_config, -> { Revox::CampaignCreateParams::CallRetryConfig }

#contactsArray<Revox::Models::CampaignCreateParams::Contact>

The list of contacts to call

Parameters:

  • value (::Array[Revox::CampaignCreateParams::Contact])

Returns:



20
# File 'lib/revox/models/campaign_create_params.rb', line 20

required :contacts, -> { Revox::Internal::Type::ArrayOf[Revox::CampaignCreateParams::Contact] }

#from_phone_numberString?

The phone number to use for outbound calls (E.164 format, e.g., +1234567890)

Parameters:

  • (String)

Returns:

  • (String, nil)


52
# File 'lib/revox/models/campaign_create_params.rb', line 52

optional :from_phone_number, String

#launchBoolean

Whether to launch the campaign immediately. Set to false to save as a draft.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


26
# File 'lib/revox/models/campaign_create_params.rb', line 26

required :launch, Revox::Internal::Type::Boolean

#max_concurrent_callsFloat?

Maximum number of concurrent calls allowed for this campaign

Parameters:

  • (Float)

Returns:

  • (Float, nil)


58
# File 'lib/revox/models/campaign_create_params.rb', line 58

optional :max_concurrent_calls, Float

#nameString

The name of the campaign

Parameters:

  • value (String)

Returns:

  • (String)


32
# File 'lib/revox/models/campaign_create_params.rb', line 32

required :name, String

#scheduled_atTime, ...

Schedule all calls in this campaign to start at a specific date and time (ISO 8601 format)

Returns:

  • (Time, Object, nil)


65
# File 'lib/revox/models/campaign_create_params.rb', line 65

optional :scheduled_at, union: -> { Revox::CampaignCreateParams::ScheduledAt }

#typeSymbol, Revox::Models::CampaignCreateParams::Type

Campaign type. 'jump_in' campaigns only dial while someone is on the campaign page and auto-pause when unattended.

Parameters:

  • value (Revox::Models::CampaignCreateParams::type_)

Returns:



39
# File 'lib/revox/models/campaign_create_params.rb', line 39

required :type, enum: -> { Revox::CampaignCreateParams::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/revox/models/campaign_create_params.rb', line 115

Instance Method Details

#to_hash{

Returns:

  • ({)


64
# File 'sig/revox/models/campaign_create_params.rbs', line 64

def to_hash: -> {