Class: Revox::Models::CampaignCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::CampaignCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/revox/models/campaign_create_params.rb,
sig/revox/models/campaign_create_params.rbs
Overview
Defined Under Namespace
Modules: ScheduledAt, Type Classes: CallRetryConfig, Contact
Instance Attribute Summary collapse
-
#assistant_id ⇒ String
The ID of the assistant to use.
-
#call_retry_config ⇒ Revox::Models::CampaignCreateParams::CallRetryConfig?
Override retry configuration for calls in this campaign.
-
#contacts ⇒ Array<Revox::Models::CampaignCreateParams::Contact>
The list of contacts to call.
-
#from_phone_number ⇒ String?
The phone number to use for outbound calls (E.164 format, e.g., +1234567890).
-
#launch ⇒ Boolean
Whether to launch the campaign immediately.
-
#max_concurrent_calls ⇒ Float?
Maximum number of concurrent calls allowed for this campaign.
-
#name ⇒ String
The name of the campaign.
-
#scheduled_at ⇒ Time, ...
Schedule all calls in this campaign to start at a specific date and time (ISO 8601 format).
-
#type ⇒ Symbol, Revox::Models::CampaignCreateParams::Type
Campaign type.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(calling_window_end_time:, calling_window_start_time:, retry_delay_seconds:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallRetryConfig::CallingWindow for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(calling_window_end_time:, calling_window_start_time:, retry_delay_seconds:) ⇒ Object
Some parameter documentations has been truncated, see Revox::Models::CampaignCreateParams::CallRetryConfig::CallingWindow for more details.
|
|
# File 'lib/revox/models/campaign_create_params.rb', line 102
|
Instance Attribute Details
#assistant_id ⇒ String
The ID of the assistant to use
14 |
# File 'lib/revox/models/campaign_create_params.rb', line 14 required :assistant_id, String |
#call_retry_config ⇒ Revox::Models::CampaignCreateParams::CallRetryConfig?
Override retry configuration for calls in this campaign. If not provided, uses the assistant's retry config.
46 |
# File 'lib/revox/models/campaign_create_params.rb', line 46 optional :call_retry_config, -> { Revox::CampaignCreateParams::CallRetryConfig } |
#contacts ⇒ Array<Revox::Models::CampaignCreateParams::Contact>
The list of contacts to call
20 |
# File 'lib/revox/models/campaign_create_params.rb', line 20 required :contacts, -> { Revox::Internal::Type::ArrayOf[Revox::CampaignCreateParams::Contact] } |
#from_phone_number ⇒ String?
The phone number to use for outbound calls (E.164 format, e.g., +1234567890)
52 |
# File 'lib/revox/models/campaign_create_params.rb', line 52 optional :from_phone_number, String |
#launch ⇒ Boolean
Whether to launch the campaign immediately. Set to false to save as a draft.
26 |
# File 'lib/revox/models/campaign_create_params.rb', line 26 required :launch, Revox::Internal::Type::Boolean |
#max_concurrent_calls ⇒ Float?
Maximum number of concurrent calls allowed for this campaign
58 |
# File 'lib/revox/models/campaign_create_params.rb', line 58 optional :max_concurrent_calls, Float |
#name ⇒ String
The name of the campaign
32 |
# File 'lib/revox/models/campaign_create_params.rb', line 32 required :name, String |
#scheduled_at ⇒ Time, ...
Schedule all calls in this campaign to start at a specific date and time (ISO 8601 format)
65 |
# File 'lib/revox/models/campaign_create_params.rb', line 65 optional :scheduled_at, union: -> { Revox::CampaignCreateParams::ScheduledAt } |
#type ⇒ Symbol, Revox::Models::CampaignCreateParams::Type
Campaign type. 'jump_in' campaigns only dial while someone is on the campaign page and auto-pause when unattended.
39 |
# File 'lib/revox/models/campaign_create_params.rb', line 39 required :type, enum: -> { Revox::CampaignCreateParams::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/revox/models/campaign_create_params.rb', line 115
|
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/revox/models/campaign_create_params.rbs', line 64
def to_hash: -> {
|