Class: Revox::Models::CampaignCreateParams::Contact

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/revox/models/campaign_create_params.rb,
sig/revox/models/campaign_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(assistant_id:, contacts:, launch:, name:, type:, call_retry_config: nil, from_phone_number: nil, max_concurrent_calls: nil, scheduled_at: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Revox::Models::CampaignCreateParams for more details.

Parameters:

  • assistant_id (String)

    The ID of the assistant to use

  • contacts (Array<Revox::Models::CampaignCreateParams::Contact>)

    The list of contacts to call

  • launch (Boolean)

    Whether to launch the campaign immediately. Set to false to save as a draft.

  • name (String)

    The name of the campaign

  • type (Symbol, Revox::Models::CampaignCreateParams::Type)

    Campaign type. 'jump_in' campaigns only dial while someone is on the campaign pa

  • call_retry_config (Revox::Models::CampaignCreateParams::CallRetryConfig) (defaults to: nil)

    Override retry configuration for calls in this campaign. If not provided, uses t

  • from_phone_number (String) (defaults to: nil)

    The phone number to use for outbound calls (E.164 format, e.g., +1234567890)

  • max_concurrent_calls (Float) (defaults to: nil)

    Maximum number of concurrent calls allowed for this campaign

  • scheduled_at (Time, Object) (defaults to: nil)

    Schedule all calls in this campaign to start at a specific date and time (ISO 86

  • request_options (Revox::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/revox/models/campaign_create_params.rb', line 91

class Contact < Revox::Internal::Type::BaseModel
  # @!attribute prompt_variables
  #
  #   @return [Hash{Symbol=>String}]
  required :prompt_variables, Revox::Internal::Type::HashOf[String]

  # @!attribute to_phone_number
  #
  #   @return [String]
  required :to_phone_number, String

  # @!method initialize(prompt_variables:, to_phone_number:)
  #   @param prompt_variables [Hash{Symbol=>String}]
  #   @param to_phone_number [String]
end

Instance Attribute Details

#prompt_variablesHash{Symbol=>String}

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


95
# File 'lib/revox/models/campaign_create_params.rb', line 95

required :prompt_variables, Revox::Internal::Type::HashOf[String]

#to_phone_numberString

Parameters:

  • value (String)

Returns:

  • (String)


100
# File 'lib/revox/models/campaign_create_params.rb', line 100

required :to_phone_number, String

Instance Method Details

#to_hash{

Returns:

  • ({)


90
# File 'sig/revox/models/campaign_create_params.rbs', line 90

def to_hash: -> {