Class: Revox::Models::CampaignUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/revox/models/campaign_update_params.rb,
sig/revox/models/campaign_update_params.rbs

Overview

See Also:

  • Revox::Resources::Campaigns#update

Defined Under Namespace

Modules: ScheduledAt, Type Classes: CallRetryConfig, Contact

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(prompt_variables:, to_phone_number:) ⇒ Object

Parameters:

  • prompt_variables (Hash{Symbol=>String})
  • to_phone_number (String)


# File 'lib/revox/models/campaign_update_params.rb', line 181

Instance Attribute Details

#assistant_idString?

The ID of the assistant to use (draft only)

Parameters:

  • (String)

Returns:

  • (String, nil)


19
# File 'lib/revox/models/campaign_update_params.rb', line 19

optional :assistant_id, String

#call_retry_configRevox::Models::CampaignUpdateParams::CallRetryConfig?

Configuration for call retry behavior including time windows, delays, and max iterations. If not provided, defaults will be used.

Parameters:

  • value (Revox::CampaignUpdateParams::CallRetryConfig, nil)

Returns:



26
# File 'lib/revox/models/campaign_update_params.rb', line 26

optional :call_retry_config, -> { Revox::CampaignUpdateParams::CallRetryConfig }, nil?: true

#contactsArray<Revox::Models::CampaignUpdateParams::Contact>?

Replace contact list (draft only)



32
# File 'lib/revox/models/campaign_update_params.rb', line 32

optional :contacts, -> { Revox::Internal::Type::ArrayOf[Revox::CampaignUpdateParams::Contact] }

#from_phone_numberString?

The phone number to use for outbound calls (draft only)

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/revox/models/campaign_update_params.rb', line 38

optional :from_phone_number, String, nil?: true

#idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/revox/models/campaign_update_params.rb', line 13

required :id, String

#max_concurrent_callsFloat?

Maximum concurrent calls (draft only)

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


44
# File 'lib/revox/models/campaign_update_params.rb', line 44

optional :max_concurrent_calls, Float, nil?: true

#nameString?

Campaign display name

Parameters:

  • (String)

Returns:

  • (String, nil)


50
# File 'lib/revox/models/campaign_update_params.rb', line 50

optional :name, String

#scheduled_atTime, ...

Scheduled start time (draft only)

Parameters:

  • value (Revox::Models::CampaignUpdateParams::scheduled_at, nil)

Returns:

  • (Time, Object, nil)


56
# File 'lib/revox/models/campaign_update_params.rb', line 56

optional :scheduled_at, union: -> { Revox::CampaignUpdateParams::ScheduledAt }, nil?: true

#typeSymbol, ...

Campaign type (draft only)



62
# File 'lib/revox/models/campaign_update_params.rb', line 62

optional :type, enum: -> { Revox::CampaignUpdateParams::Type }

Class Method Details

.variantsArray(Time, Object)

Returns:

  • (Array(Time, Object))


# File 'lib/revox/models/campaign_update_params.rb', line 218

Instance Method Details

#to_hash{

Returns:

  • ({)


64
# File 'sig/revox/models/campaign_update_params.rbs', line 64

def to_hash: -> {