Class: Revox::Models::CampaignUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Revox::Models::CampaignUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/revox/models/campaign_update_params.rb,
sig/revox/models/campaign_update_params.rbs
Overview
Defined Under Namespace
Modules: ScheduledAt, Type Classes: CallRetryConfig, Contact
Instance Attribute Summary collapse
-
#assistant_id ⇒ String?
The ID of the assistant to use (draft only).
-
#call_retry_config ⇒ Revox::Models::CampaignUpdateParams::CallRetryConfig?
Configuration for call retry behavior including time windows, delays, and max iterations.
-
#contacts ⇒ Array<Revox::Models::CampaignUpdateParams::Contact>?
Replace contact list (draft only).
-
#from_phone_number ⇒ String?
The phone number to use for outbound calls (draft only).
- #id ⇒ String
-
#max_concurrent_calls ⇒ Float?
Maximum concurrent calls (draft only).
-
#name ⇒ String?
Campaign display name.
-
#scheduled_at ⇒ Time, ...
Scheduled start time (draft only).
-
#type ⇒ Symbol, ...
Campaign type (draft only).
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(prompt_variables:, to_phone_number:) ⇒ Object
|
|
# File 'lib/revox/models/campaign_update_params.rb', line 181
|
Instance Attribute Details
#assistant_id ⇒ String?
The ID of the assistant to use (draft only)
19 |
# File 'lib/revox/models/campaign_update_params.rb', line 19 optional :assistant_id, String |
#call_retry_config ⇒ Revox::Models::CampaignUpdateParams::CallRetryConfig?
Configuration for call retry behavior including time windows, delays, and max iterations. If not provided, defaults will be used.
26 |
# File 'lib/revox/models/campaign_update_params.rb', line 26 optional :call_retry_config, -> { Revox::CampaignUpdateParams::CallRetryConfig }, nil?: true |
#contacts ⇒ Array<Revox::Models::CampaignUpdateParams::Contact>?
Replace contact list (draft only)
32 |
# File 'lib/revox/models/campaign_update_params.rb', line 32 optional :contacts, -> { Revox::Internal::Type::ArrayOf[Revox::CampaignUpdateParams::Contact] } |
#from_phone_number ⇒ String?
The phone number to use for outbound calls (draft only)
38 |
# File 'lib/revox/models/campaign_update_params.rb', line 38 optional :from_phone_number, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/revox/models/campaign_update_params.rb', line 13 required :id, String |
#max_concurrent_calls ⇒ Float?
Maximum concurrent calls (draft only)
44 |
# File 'lib/revox/models/campaign_update_params.rb', line 44 optional :max_concurrent_calls, Float, nil?: true |
#name ⇒ String?
Campaign display name
50 |
# File 'lib/revox/models/campaign_update_params.rb', line 50 optional :name, String |
#scheduled_at ⇒ Time, ...
Scheduled start time (draft only)
56 |
# File 'lib/revox/models/campaign_update_params.rb', line 56 optional :scheduled_at, union: -> { Revox::CampaignUpdateParams::ScheduledAt }, nil?: true |
#type ⇒ Symbol, ...
Campaign type (draft only)
62 |
# File 'lib/revox/models/campaign_update_params.rb', line 62 optional :type, enum: -> { Revox::CampaignUpdateParams::Type } |
Class Method Details
.variants ⇒ Array(Time, Object)
|
|
# File 'lib/revox/models/campaign_update_params.rb', line 218
|
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/revox/models/campaign_update_params.rbs', line 64
def to_hash: -> {
|